formats = [
    "：令和5年2月9日（木） ～ 令和5年9月29日（金）※17時必着 （予算がなくなり次第、予告なく募集を終了します。） ・",
    "転入後3か月から1年以内（申請時には就業後3か月以上経過していること）",
    "工事請負契約又は売買契約締結の日から２ヶ月以内。",
    "大学の正規の最短修学年限",
    "県から交付された特定不妊治療費助成事業承認決定通知書の交付日から1年以内",
    "・施工業者との契約後速やかに（遅くても屋根工事完了前までに）申込書類を提出してください。 ・修繕、模様替えの場合は着工前一週間前までに申し込み書類を提出してください。",
    "令和2年4月1日から令和5年3月31日 （請求期間が過ぎると第十一回特別弔慰金を受けることができなくなりますので、ご注意ください）",
    "健康診査を受けた日から6か月以内",
    "令和5年4月3日（月）から令和6年3月29日（金）まで ※ 1頭の猫に対して申請できるのは1回までです。 ※ 補助金交付予定額が予算に達した時点で締め切ります。",
    "令和5年2月28日まで",
    "令和5 年4 月24日（月）～令和4年5月19日（金）",
    "令和５年４月１日から令和６年３月３１日まで ※ただし、予算に達した時点で申し込みを締め切りますので、ご注意ください ■問い合わせ先",
    "令和4年8月31日 17時15分まで",
    "令和4年6月22日 ～ 令和4年10月31日",
    "提出先",
    "受診をした月から、なるべく1年以内 ※ 申請できる権利は5年で消滅となります",
    "令和4年7月1日(金曜日)から令和5年2月28日(火曜日) (注意)郵送必着",
    "令和4年2月4日(金曜日)から令和4年9月30日(金曜日)まで",
    "令和2(2020)年4月1日～令和5(2023)年3月31日",
    "令和９年３月３１日まで",
    "検査日が令和4年4月1日～ 令和5年5月7日検査分 まで",
    "年度をまたいで治療継続中の方は、治療実施翌年度の6月から3月末の期間",
    "第 1 回申請受付期間：平成 23 年12 月 1 日から平成 24 年3 月21 日",
    "・・・ 金融機関との協議による",
    "物件登録者 初めて登録された日から2年以内",
    "申請期間：令和4年7月4日（月曜日）～令和4年9月30日（金曜日） 申請は、先着順に受付いたします。 ただし、申請額が予算額を超えた日に複数の申請があった場合は、その日の申請人全員を対象とした抽選を別途行います。",
    "清掃日又は11条検査受検日のいずれか遅い日の3か月後まで （遅れると申請ができません。）",
    "：5月8日（金）～8月31日(月） ※オンライン申請は5月11日（月）から受付",
    "平成25年2月8日（金）から平成25年2月21日（木）まで 意見受付期間 平成25年2月8日（金）から平成25年2月21日（木）まで",
    "災害等による損害を受けた日から1年間",
    "在学している学校の修業年限です。",
    "令和5年5月8日（月曜日）～令和5年12月15日（金曜日）",
    "災害を受けた日から30日以内",
    "新築住宅=最長3年間（最大30万円）",
    "受付期間：令和5年10月31日（火曜日）まで",
    "令和5年4月1日から令和6年3月11日まで",
    "令和４年５月１６日（月）から ※ただし、受け付けできる件数に限りがございますので、ご了承ください。",
    "令和5年4月1日から令和6年3月31日",
    "令和４年６月１日から令和４年１０月３１日 午前９時から午後５時まで",
    "随時",
    "1または2のいずれか早い日までです。",
    "令和2年4月1日～令和5年3月31日 (請求期間を過ぎると第十一回特別弔慰金を受けることができなくなりますので、ご注意ください。)",
    "6月1日から11月30日まで ※1組織申請受付期間内1回の申請になります。 ※申請書一式は毎年5月下旬に横須賀市に結成を届出た「自主防災組織」の町内会・自治会長に配布します。",
    "毎年4月1日～5月末（途中申請の場合は、翌年1月末まで随時受け付けますが、受付翌月からの援助となります。）",
    "治療を受けた月の属する年度内（4月1日から翌年3月31日まで） とします。",
    "平成30年４月から 申請は各年度の初回のみ必要で、以後は支給額がある場合に、指定振込先へ振り込みます。 初回申請以降は毎年７月に申請が必要です。",
    "随時",
    "随時受け付けています。 予算に達し次第終了となります。",
    "禁煙外来治療終了日から1年以内の申請に限ります",
    "申請時期：本市に転入し上記に掲げる、「移住元要件」「移住先要件」及び「地域の担い手としての役割に関する要件」を満たした後。",
    "○4月1日～ 先着順 予算枠に達ししだい終了となります。 ○補助金交付決定は、4月中旬以降の予定です。 （申請様式等は下方にあります。↓）",
    "2022年4月15日(金曜日)～2023年3月31日(金曜日)まで。",
    "奨学金の貸与が決まった年度の４月から在学する学校の正規の修学期間",
    "毎年 年度末 3月20日まで（休日の場合は前日）",
    "医学生 6年以内",
    "令和2年4月1日から令和5年3月31日",
    "令和6年3月29日（金曜日）まで（書類必着）",
    "高校入学前の中学3年時の3月 （※詳しい日程については、毎年、中学3年生を対象に配布する募集案内に記載します。）",
    "令和５(2023)年４月3日（月）から令和６(2024)年３月29日（金）まで",
    "令和5年5月1日（月）から令和6年2月23日（金）まで",
    "令和4年9月30日（金曜日） ※当日消印有効",
    "貸与を受けた年度の3月末日まで",
    "令和５年４月１日より補助金額が変更となります。",
    "4月1日から受け付けます。その年度の3月31日までに完了する事業が対象です。",
    "年度当初の認定の場合、在校生は1月～2月、新1年生は4月上旬までです。 年度途中に生活状態が悪化した場合は、随時受け付けます。",
    "令和4年12月1日から令和5年1月31日まで（消印有効）",
    "令和4年11月30日まで （受付は終了しました）",
    "令和２年４月１日から令和５年３月３１日まで （請求期間を過ぎると第十一回特別弔慰金を受けることができなくなりますので、ご注意ください。）",
    "開庁時間内 随時",
    "毎年3月～ 4月(詳しくは、市のHPでお知らせします。)",
    "令和2年4月1日から令和5年3月31日 （請求期間を過ぎると第十一回特別弔慰金を受けることができなくなりますので、ご注意ください）",
    "就職活動を行った日から6か月以内",
    "学校における正規の修学期間",
    "令和4年度分 は、 令和4年度末 に資格を取得したことになどより、 令和5年4月以後に納期限 が設定されているもの。",
    "申込書：申込み期限 住宅の引き渡しの概ね１０日前まで（住宅の引渡し時点で申込書の受理通知が発行されていること） 申請書：申請期限",
    "毎年7月分～次年6月分 毎年7月1日から、随時申請できます。",
    "奨励措置期間は課税年度から10年以内とする。",
    "令和5年5月22日(月曜日)から令和5年9月29日(金曜日)",
    "令和５年４月１７日から 令和５年１１月３０日まで",
    "治療の種類によって申請期間が異なります（年度内申請ではなくなりました）。 ＊やむを得ない理由で申請期限を過ぎてしまう場合は、あらかじめ保健相談センターへご連絡ください。",
    "原則3か月以内（状況に応じて3か月以内での延長貸付や再貸付が受けられる場合あり） 注 要相談",
    "令和4年3月31日まで",
    "令和2年4月1日から 令和5年3月31日 まで（期間を過ぎると請求ができませんのでご注意ください）",
    "令和７年３月31日まで(必着)",
    "令和2年5月25日(月)～令和2年9月25日(金) ※土日祝日を除く8時30分～17時15分 申請先 上士幌町役場保健福祉課福祉担当窓口(郵送申請も可)",
    "令和3年(2021年)4月1日（木曜日)〜令和4年(2022年)3月31日(木曜日)",
    "令和3年5月19日（水曜日）から令和4年2月28日（月曜日）まで",
    "最後の妊婦健康診査受診日から6カ月以内",
    "随時",
    "令和4年8月1日月曜日から",
    "・1年間の診療分について、診療期間終了後の 3か月以内 までに申請を行う。",
    "令和元年 ８月１日 （木）～ 令和２ 年２月３日（月）",
    "助成対象講座を修了した日から3か月以内",
    "毎年4月1日から3月31日まで",
    "令和4年7月中旬の賦課決定通知書到着後から令和5年3月31日（当日消印有効）"
]